==> zio-aws-chimesdkmessaging_2.13-5.17.158.2-sources.jar: zio/aws/chimesdkmessaging/model/ListChannelMessagesResponse.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.chimesdkmessaging.model.primitives.{NextToken, ChimeArn}
import scala.jdk.CollectionConverters._
final case class ListChannelMessagesResponse(
    channelArn: Option[ChimeArn] = None,
    nextToken: Option[NextToken] = None,
    channelMessages: Option[
      Iterable[zio.aws.chimesdkmessaging.model.ChannelMessageSummary]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelMessagesResponse = {
    import ListChannelMessagesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelMessagesResponse
      .builder()
      .optionallyWith(
        channelArn.map(value => ChimeArn.unwrap(value): java.lang.String)
      )(_.channelArn)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        channelMessages.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.channelMessages)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.ListChannelMessagesResponse.ReadOnly =
    zio.aws.chimesdkmessaging.model.ListChannelMessagesResponse
      .wrap(buildAwsValue())
}
object ListChannelMessagesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelMessagesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.ListChannelMessagesResponse =
      zio.aws.chimesdkmessaging.model.ListChannelMessagesResponse(
        channelArn.map(value => value),
        nextToken.map(value => value),
        channelMessages.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def channelArn: Option[ChimeArn]
    def nextToken: Option[NextToken]
    def channelMessages: Option[
      List[zio.aws.chimesdkmessaging.model.ChannelMessageSummary.ReadOnly]
    ]
    def getChannelArn: ZIO[Any, AwsError, ChimeArn] =
      AwsError.unwrapOptionField("channelArn", channelArn)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getChannelMessages: ZIO[Any, AwsError, List[
      zio.aws.chimesdkmessaging.model.ChannelMessageSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("channelMessages", channelMessages)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelMessagesResponse
  ) extends zio.aws.chimesdkmessaging.model.ListChannelMessagesResponse.ReadOnly {
    override val channelArn: Option[ChimeArn] = scala
      .Option(impl.channelArn())
      .map(value => zio.aws.chimesdkmessaging.model.primitives.ChimeArn(value))
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.chimesdkmessaging.model.primitives.NextToken(value))
    override val channelMessages: Option[
      List[zio.aws.chimesdkmessaging.model.ChannelMessageSummary.ReadOnly]
    ] = scala
      .Option(impl.channelMessages())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.chimesdkmessaging.model.ChannelMessageSummary.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelMessagesResponse
  ): zio.aws.chimesdkmessaging.model.ListChannelMessagesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-chimesdkmessaging_2.13-5.17.163.1-sources.jar: zio/aws/chimesdkmessaging/model/ListChannelMessagesResponse.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.chimesdkmessaging.model.primitives.{NextToken, ChimeArn}
import scala.jdk.CollectionConverters._
final case class ListChannelMessagesResponse(
    channelArn: Optional[ChimeArn] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent,
    channelMessages: Optional[
      Iterable[zio.aws.chimesdkmessaging.model.ChannelMessageSummary]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelMessagesResponse = {
    import ListChannelMessagesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelMessagesResponse
      .builder()
      .optionallyWith(
        channelArn.map(value => ChimeArn.unwrap(value): java.lang.String)
      )(_.channelArn)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(
        channelMessages.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.channelMessages)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.ListChannelMessagesResponse.ReadOnly =
    zio.aws.chimesdkmessaging.model.ListChannelMessagesResponse
      .wrap(buildAwsValue())
}
object ListChannelMessagesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelMessagesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.ListChannelMessagesResponse =
      zio.aws.chimesdkmessaging.model.ListChannelMessagesResponse(
        channelArn.map(value => value),
        nextToken.map(value => value),
        channelMessages.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def channelArn: Optional[ChimeArn]
    def nextToken: Optional[NextToken]
    def channelMessages: Optional[
      List[zio.aws.chimesdkmessaging.model.ChannelMessageSummary.ReadOnly]
    ]
    def getChannelArn: ZIO[Any, AwsError, ChimeArn] =
      AwsError.unwrapOptionField("channelArn", channelArn)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getChannelMessages: ZIO[Any, AwsError, List[
      zio.aws.chimesdkmessaging.model.ChannelMessageSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("channelMessages", channelMessages)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelMessagesResponse
  ) extends zio.aws.chimesdkmessaging.model.ListChannelMessagesResponse.ReadOnly {
    override val channelArn: Optional[ChimeArn] = zio.aws.core.internal
      .optionalFromNullable(impl.channelArn())
      .map(value => zio.aws.chimesdkmessaging.model.primitives.ChimeArn(value))
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.chimesdkmessaging.model.primitives.NextToken(value))
    override val channelMessages: Optional[
      List[zio.aws.chimesdkmessaging.model.ChannelMessageSummary.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.channelMessages())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.chimesdkmessaging.model.ChannelMessageSummary.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.ListChannelMessagesResponse
  ): zio.aws.chimesdkmessaging.model.ListChannelMessagesResponse.ReadOnly =
    new Wrapper(impl)
}
